/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2004 Dr. Lars H. Hahn

*/

package haushalt.auswertung;

import java.awt.Font;

import haushalt.auswertung.bloecke.LeererBlock;
import haushalt.auswertung.bloecke.TabellenBlock;
import haushalt.auswertung.bloecke.TextBlock;
import haushalt.daten.Datenbasis;
import haushalt.daten.Euro;
import haushalt.daten.Kategorie;
import haushalt.daten.zeitraum.AbstractZeitraum;
import haushalt.daten.zeitraum.Jahr;
import haushalt.gui.Haushalt;
import haushalt.gui.generischerdialog.AbstractGDPane;
import haushalt.gui.generischerdialog.EinOderAlleRegisterGDP;
import haushalt.gui.generischerdialog.ZeitraumGDP;

/**
 * @author Dr. Lars H. Hahn
 * @version 2.0/2004.08.22
 */
public class BAAbsoluterVergleich extends AbstractBlockAuswertung {

	public static final String ueberschrift = "Tabelle absoluter Vergleich";
	
  public BAAbsoluterVergleich(Haushalt haushalt, Datenbasis db, String name) {
    super(haushalt, db, name);
    AbstractGDPane[] panes = new AbstractGDPane[3];
		panes[0] = new ZeitraumGDP("Erster Zeitraum:", new Jahr(2003));
		panes[1] = new ZeitraumGDP("Zweiter Zeitraum:", new Jahr(2004));
		panes[2] = new EinOderAlleRegisterGDP("Register:", db.getRegisterNamen(), null);
		erzeugeEigenschaften(haushalt.getFrame(), ueberschrift, panes);
  }

  protected String berechneAuswertung(Object[] werte) {
  	AbstractZeitraum zeitraum1 = (AbstractZeitraum) werte[0];
		AbstractZeitraum zeitraum2 = (AbstractZeitraum) werte[1];
    String register = (String) werte[2];
    Kategorie[] kategorien = db.getKategorien();
		int anzKat = kategorien.length;
		Euro[] summen1 = db.getKategorieSalden(zeitraum1, register);
		Euro[] summen2 = db.getKategorieSalden(zeitraum2, register);
		tabelle = new String[anzKat+2][4];
		tabelle[0][0] = "Kategorie";
		tabelle[0][1] = ""+zeitraum1;
		tabelle[0][2] = ""+zeitraum2;
		tabelle[0][3] = "Differenz";
		tabelle[anzKat+1][0] = "S U M M E";

		Euro summe1 = new Euro();
		Euro summe2 = new Euro();		
		for(int i=0;i<anzKat;i++) {
			tabelle[i+1][0] = ""+kategorien[i];
			tabelle[i+1][1] = ""+summen1[i];
			tabelle[i+1][2] = ""+summen2[i];
			tabelle[i+1][3] = ""+summen1[i].sub(summen2[i]);
			summe1.sum(summen1[i]);
			summe2.sum(summen2[i]);
		}
		tabelle[anzKat+1][1] = ""+summe1;
		tabelle[anzKat+1][2] = ""+summe2;
		tabelle[anzKat+1][3] = ""+summe1.sub(summe2);

		// Vorhandene Blcke lschen und neu berechnete einfgen
		String titel = "Absoluter Vergleich ("+tabelle[0][1]+" und "+tabelle[0][2];
		if(register == null)
		  titel += ")";
		else
		  titel += ", " + register + ")";
		loescheBloecke();
		TextBlock block1 = new TextBlock(titel);
		block1.setFont(new Font(haushalt.getFontname(), Font.BOLD, haushalt.getFontgroesse()+6));
		addDokumentenBlock(block1);
		addDokumentenBlock(new LeererBlock(1));
		TabellenBlock block2 = new TabellenBlock(tabelle);
		block2.setFont(new Font(haushalt.getFontname(), Font.PLAIN, haushalt.getFontgroesse()));
    final int[] attribute = {TabellenBlock.LINKS, TabellenBlock.RECHTS, TabellenBlock.RECHTS, TabellenBlock.RECHTS};
    block2.setAusrichtung(attribute);
		addDokumentenBlock(block2);
    return titel;
  }

}
