/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2004 Dr. Lars H. Hahn

*/

package haushalt.auswertung;

import haushalt.auswertung.bloecke.AbstractBlock;
import haushalt.auswertung.bloecke.LeererBlock;
import haushalt.auswertung.bloecke.TabellenBlock;
import haushalt.auswertung.bloecke.TextBlock;
import haushalt.daten.AbstractBuchung;
import haushalt.daten.Datenbasis;
import haushalt.daten.Euro;
import haushalt.daten.Kategorie;
import haushalt.daten.zeitraum.AbstractZeitraum;
import haushalt.daten.zeitraum.Jahr;
import haushalt.gui.Haushalt;
import haushalt.gui.generischerdialog.AbstractGDPane;
import haushalt.gui.generischerdialog.EinOderAlleRegisterGDP;
import haushalt.gui.generischerdialog.MehrereKategorienGDP;
import haushalt.gui.generischerdialog.ZeitraumGDP;

import java.awt.Font;

/**
 * @author Dr. Lars H. Hahn
 * @version 2.0/2004.08.22
 */
public class BAKategorieAusgabe extends AbstractBlockAuswertung {
  private final boolean DEBUG = false;

	public static final String ueberschrift = "Tabelle ausgewhlte Buchungen";

  public BAKategorieAusgabe(Haushalt haushalt, Datenbasis db, String name) {
    super(haushalt, db, name);
    AbstractGDPane[] panes = new AbstractGDPane[3];
		panes[0] = new ZeitraumGDP("Zeitraum:", new Jahr(2004));
		panes[1] = new EinOderAlleRegisterGDP("Register:", db.getRegisterNamen(), null);
    panes[2] = new MehrereKategorienGDP("Kategorien:", db.getKategorien());
		erzeugeEigenschaften(haushalt.getFrame(), ueberschrift, panes);
  }

  protected String berechneAuswertung(Object[] werte) {
  	AbstractZeitraum zeitraum = (AbstractZeitraum) werte[0];
    String register = (String) werte[1];
    Kategorie[] kategorien = (Kategorie[]) werte[2];

    AbstractBuchung[] buchungen = db.getBuchungen(zeitraum, register, kategorien);
    int anzahl = buchungen.length;
    tabelle = new String[anzahl][4];
    Euro summe = new Euro();
    for(int i=0; i<anzahl; i++) {
      summe.sum(buchungen[i].getWert());
      tabelle[i] = buchungen[i].getZeile();
    }
    if(DEBUG)
      System.out.println(""+anzahl+" Buchungen im Zeitraum "+zeitraum);

		// Vorhandene Blcke lschen und neu berechnete einfgen
    String titel = "Ausgewhlte Buchungen ("+zeitraum;
    if(register == null)
      titel += " / Alle Register)";
    else
      titel += " / "+register+")";
		loescheBloecke();
		AbstractBlock block1 = new TextBlock(titel);
		block1.setFont(new Font(haushalt.getFontname(), Font.BOLD, haushalt.getFontgroesse()+6));
		addDokumentenBlock(block1);
		addDokumentenBlock(new LeererBlock(1));
    if(anzahl == 0) {
      String hinweis = "Keine Buchung mit diesen Eigenschaften!";
			AbstractBlock block2 = new TextBlock(hinweis);
			addDokumentenBlock(block2);
    }
    else {
	    final double[] relTabs = {0.0, 12.0, 50.0, 80.0};
	    final int[] attribute = {TabellenBlock.LINKS, TabellenBlock.LINKS, TabellenBlock.LINKS, TabellenBlock.RECHTS};
	    TabellenBlock block2 = new TabellenBlock(tabelle);
			block2.setFont(new Font(haushalt.getFontname(), Font.PLAIN, haushalt.getFontgroesse()));
	    block2.setRelTabs(relTabs);
	    block2.setLinienFarbe("Wei");
	    block2.setAusrichtung(attribute);
	    addDokumentenBlock(block2);
	    String[][] text = {{"", "Summe:", "", ""+summe}};
	    TabellenBlock block3 = new TabellenBlock(text);
			block3.setFont(new Font(haushalt.getFontname(), Font.ITALIC, haushalt.getFontgroesse()));
	    block3.setRelTabs(relTabs);
	    block3.setHgFarbe("Grau");
	    block3.setLinienFarbe("Grau");
	    block3.setAusrichtung(attribute);
	    addDokumentenBlock(block3);
    }
    return titel;
  }

}
