/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2004 Dr. Lars H. Hahn

*/

package haushalt.auswertung.bloecke;

import java.awt.Graphics;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/**
 * @author Dr. Lars H. Hahn
 * @version 2.0/2004.08.22
 */
public class TextBlock extends AbstractBlock {

  private final String text;

  public TextBlock(String text) {
    this.text = text;
  }  

  private List textUmbrechen(Graphics g, int breite) {
    List zeilen = new ArrayList();
    String zeile = "";
    StringTokenizer woerter = new StringTokenizer(text, " ", true);
    while(woerter.hasMoreTokens()) {
      String wort = woerter.nextToken();
      byte[] zeichen = (zeile+wort).getBytes();
      if(g.getFontMetrics().bytesWidth(zeichen,0,zeichen.length) > breite) {
        zeilen.add(zeile);
        zeile = "";
      }
      zeile += wort;
    }
    zeilen.add(zeile);
    return zeilen;
  }
  
  public int paint(Graphics g, int xStart, int yStart, int breite) {
    g.setFont(getFont());
    int textBreite = breite - 2 * getAbsRand(breite);
    List zeilen = textUmbrechen(g, textBreite);
    int y = yStart;
    int x = xStart + getAbsRand(breite);
    for(int i=0; i<zeilen.size(); i++) {
      int yZeile = y + g.getFontMetrics().getHeight() - g.getFontMetrics().getDescent();
      g.drawString(""+zeilen.get(i), x, yZeile);
      y += g.getFontMetrics().getHeight();
    }
    return zeilen.size() * g.getFontMetrics().getHeight();
  }
  
  private List printZeilen = null;
  
  public int print(Graphics g, int zeile, int xStart, int yStart, int hoehe, int breite) {
    g.setFont(getFont());
    int textBreite = breite - 2 * getAbsRand(breite);
    if(printZeilen == null)
      printZeilen = textUmbrechen(g, textBreite);
    if(zeile >= printZeilen.size())
      return -1;
    if(g.getFontMetrics().getHeight() > hoehe)
      return 0;
    int x = xStart + getAbsRand(breite);
    int y = yStart + g.getFontMetrics().getHeight() - g.getFontMetrics().getDescent();
    g.drawString(""+printZeilen.get(zeile), x, y);
    return g.getFontMetrics().getHeight();
  }

}
