/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2004 Dr. Lars H. Hahn

*/

package haushalt.gui;


import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.URL;
import java.net.URLClassLoader;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JToolBar;
import javax.swing.KeyStroke;

/**
 * @author Dr. Lars H. Hahn
 * @version 2.0/2004.08.22
 */
public class ActionHandler {
	private final boolean DEBUG = false;

  final private String[] hauptmenu = {
  	"Datei", "Bearbeiten", "Ausgabe", "Extras", "Hilfe"
  };
  final private Object[] alleActions;
	final private Object[][] menuDateiText = {
		{"neu", "Neu", "New", "Legt ein neues Haushaltsbuch an", new Integer(KeyEvent.VK_N)},
		{"laden", "Laden...", "Open", "Ldt ein Haushaltsbuch", new Integer(KeyEvent.VK_L)}, 
		{"speichern", "Speichern", "Save", "Speichert ein Haushaltsbuch", new Integer(KeyEvent.VK_S)},
		{"speichernUnter", "Speichern unter...", "SaveAs", "Speichert ein Haushaltsbuch unter einem neuen Namen", null},
		{"beenden", "Beenden", null, "Beendet jHaushalt", new Integer(KeyEvent.VK_X)}
	};
	final private Object[][] menuBearbeitenText = {
		{"umbuchen", "Umbuchung eingeben...", "Umbuchung", "Erstellt eine neue Umbuchung", new Integer(KeyEvent.VK_U)},
		{"loeschen", "Buchung lschen...", "Delete", "Lscht eine Buchung", new Integer(KeyEvent.VK_D)},
		{"splitten", "Buchung splitten...", "Splitten", "Splittet eine Buchung", new Integer(KeyEvent.VK_P)},
		{"neuesRegister", "Neues Register...", "Register", "Erzeugt ein neues Register", new Integer(KeyEvent.VK_R)},
		{"kategorienBearbeiten", "Kategorien bearbeiten...", "Auto", "Erzeugen und Umbenennen von Kategorien", new Integer(KeyEvent.VK_K)},
		{"suchen", "Suchen und Ersetzen...", "Find", "Sucht nach Text in allen Buchungen.", null},
		{"alteBuchungenLoeschen", "Alte Buchungen entfernen...", null, "Lscht alle Buchungen vor einem Datum", new Integer(KeyEvent.VK_E)},
		{"kategorieErsetzen", "Kategorie ersetzen...", null, "Ersetzt eine Kategorie", null},
		{"registerVereinigen", "Register vereinigen...", null, "Fhrt zwei Register zusammen", new Integer(KeyEvent.VK_V)}
	};
	final private Object[][] menuAusgabeText = {
		{"zeigeAuswertung", "Auswertungen...", "Auswertung", "Zeigt die Auswertungen an", new Integer(KeyEvent.VK_A)},
		{"druckerEinrichten", "Drucker einrichten...", "PageSetup" , "Richtet den Drucker ein", null}
	};
	final private Object[][] menuExtrasText = {
		{"optionen", "Optionen...", "Preferences", "Verndert die optionalen Einstellungen", new Integer(KeyEvent.VK_O)},
		{"autoBuchung", "Automatische Buchungen...", "Robot", "Automatische Buchungen bearbeiten", null},
		{"importCSV", "Import CSV...", "Import", "Importiert eine CSV-Datei", new Integer(KeyEvent.VK_I)},
		{"importQuicken", "Import QIF...", null, "Importiert eine QIF-Datei", new Integer(KeyEvent.VK_Q)}
	};
	final private Object[][] menuHilfeText = {
		{"hilfeInhalt", "Inhalt...", "Help", "ffnet die Hilfe", new Integer(KeyEvent.VK_F1)},
		{"programmInfo", "Programm Informationen...", "Information", "Zeigt Informationen zu jHaushalt", null}
	};

  protected final Haushalt haushalt;
  
  public ActionHandler(Haushalt haushalt) {
    super();
    this.haushalt = haushalt;
    alleActions = new Object[hauptmenu.length];
		alleActions[0] = erzeugeAction(menuDateiText);
		alleActions[1] = erzeugeAction(menuBearbeitenText);
		alleActions[2] = erzeugeAction(menuAusgabeText);
		alleActions[3] = erzeugeAction(menuExtrasText);
		alleActions[4] = erzeugeAction(menuHilfeText);
  }
  
	private HaushaltAction[] erzeugeAction(Object[][] text) {
		int anzahl = text.length;
		HaushaltAction[] action = new HaushaltAction[anzahl];
		for(int i=0; i<anzahl; i++) {
			action[i] = new HaushaltAction(text[i]);
		}
		if(DEBUG)
		  System.out.println("ActionHandler: Action-Liste erzeugt.");
		return action;
	}
	
	public JMenuBar erzeugeMenuBar() {
		JMenuBar menuBar = new JMenuBar();
		for(int i=0; i<hauptmenu.length; i++) {
			JMenu menu = new JMenu(hauptmenu[i]);
			Action[] action = (Action[]) alleActions[i];
			for(int j=0; j<action.length; j++) {
        JMenuItem menuItem = new JMenuItem(action[j]);
        menu.add(menuItem);
      }
			menuBar.add(menu);      
    }
	  return menuBar;
	}

	public JToolBar erzeugeToolBar() {
		JToolBar toolBar = new JToolBar();
		for(int i=0; i<hauptmenu.length; i++) {
			HaushaltAction[] action = (HaushaltAction[]) alleActions[i];
			for(int j=0; j<action.length; j++) {
				ImageIcon bigIcon = action[j].getBigIcon();
				if(bigIcon != null) {
					JButton button = new JButton(action[j]);
					button.setText("");
					button.setIcon(bigIcon);
					toolBar.add(button);
				}
			}
		}
		 return toolBar;
	}
	
	protected ImageIcon createBigIcon(Object iconname) {
		if(iconname == null)
			return null;
		URLClassLoader urlLoader = (URLClassLoader)getClass().getClassLoader();
		URL imageURL = urlLoader.findResource("res/" + iconname + "24.gif");
		if(DEBUG)
			System.out.println("ActionHandler: Erzeuge Image "+iconname+"@"+imageURL);
		return new ImageIcon(imageURL);
	}
	
	protected ImageIcon createSmallIcon(Object iconname) {
		if(iconname == null)
			iconname = "Leer";
		URLClassLoader urlLoader = (URLClassLoader)getClass().getClassLoader();
		URL imageURL = urlLoader.findResource("res/" + iconname + "16.gif");
		if(DEBUG)
			System.out.println("ActionHandler: Erzeuge Image "+iconname+"@"+imageURL);
		return new ImageIcon(imageURL);
	}
	
	private class HaushaltAction extends AbstractAction {
		private final String name;
		private final ImageIcon bigIcon;
		HaushaltAction(Object[] text) {
			super((String)text[1], createSmallIcon(text[2]));
			name = (String)text[0];
			bigIcon = createBigIcon(text[2]);
			putValue(SHORT_DESCRIPTION, text[3]);
			if(text[4] != null) {
	  		putValue(MNEMONIC_KEY, text[4]);
  			int code = ((Integer)text[4]).intValue();
				putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(code, ActionEvent.CTRL_MASK));
			}
		}
		public ImageIcon getBigIcon() {
			return bigIcon;
		}
		public void actionPerformed(ActionEvent e) {
			Method call;
      try {
        call = Haushalt.class.getMethod(name, null);
				call.invoke(haushalt, null);
      } catch (SecurityException e1) {
        e1.printStackTrace();
      } catch (NoSuchMethodException e1) {
        e1.printStackTrace();
      } catch (IllegalArgumentException e1) {
        e1.printStackTrace();
      } catch (IllegalAccessException e1) {
        e1.printStackTrace();
      } catch (InvocationTargetException e1) {
        e1.printStackTrace();
      }
		}
	}

}
