/*

This file is part of jHaushalt.

jHaushalt is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

jHaushalt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jHaushalt; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(C)opyright 2002-2004 Dr. Lars H. Hahn

*/

package haushalt.gui;

import haushalt.daten.zeitraum.*;

import javax.swing.JComboBox;

/**
 * Stellt die Auswahlbox fr die verschiedenen Zeitrume bereit.
 *
 * @author Dr. Lars H. Hahn
 * @version 2.0/2004.08.22
 */

public class ZeitraumComboBox extends JComboBox {

  private static final String[] items = {
    "Monat (MM/JJJJ)",
    "Quartal (Q/JJJJ)",
    "Halbjahr (H/JJJJ)",
    "Jahr (JJJJ)",
    "Volles Jahr bis Datum (TT.MM.JJJJ)",
    "Volles Jahr bis Heute",
    "Jahresanfang bis Datum (TT.MM.JJJJ)",
    "Jahresanfang bis Heute",
    "Freier Zeitraum (TT.MM.JJJJ-TT.MM.JJJJ)"
    };

	/**
	 * Es wird der Zeitraum passend zur Klasse des Parameters vorausgewlt.
	 * Wird <b>null<b> bergeben, wird der Zeitraum 'Monat' gewhlt.
	 * @param zeitraum Objekt vom Typ 'ZeitIntervall' zur Auswahl des passenden
	 * Eintrags in der ComboBox 
	 */
	public ZeitraumComboBox(final AbstractZeitraum zeitraum) {
		super(items);
		waehleZeitraum(zeitraum);
	}
	
	public void waehleZeitraum(final AbstractZeitraum zeitraum) {
		if(zeitraum == null)
			setSelectedIndex(0);
		else if(zeitraum.getClass() == Quartal.class)
			setSelectedIndex(1);
		else if(zeitraum.getClass() == Halbjahr.class)
			setSelectedIndex(2);
		else if(zeitraum.getClass() == Jahr.class)
			setSelectedIndex(3);
		else if(zeitraum.getClass() == VollesJahrBisDatum.class)
			setSelectedIndex(4);
		else if(zeitraum.getClass() == VollesJahrBisHeute.class)
			setSelectedIndex(5);
		else if(zeitraum.getClass() == JahresanfangBisDatum.class)
			setSelectedIndex(6);
		else if(zeitraum.getClass() == JahresanfangBisHeute.class)
			setSelectedIndex(7);
		else if(zeitraum.getClass() == FreierZeitraum.class)
		  setSelectedIndex(8);
	  else
			setSelectedIndex(0);
	}

  /**
   * Erzeugt aus dem ausgewhlten Eintrag der ComboBox und dem bergebenen
   * Text einen neuen Zeitraum.
   * @param text Wert des Zeitraums
   * @return erzeugter Zeitraum
   */
  public AbstractZeitraum getZeitraum(final String text) {
    switch(getSelectedIndex()) {
      case 0: return new Monat(text);
      case 1: return new Quartal(text);
      case 2: return new Halbjahr(text);
      case 3: return new Jahr(text);
      case 4: return new VollesJahrBisDatum(text);
      case 5: return new VollesJahrBisHeute(text);
      case 6: return new JahresanfangBisDatum(text);
      case 7: return new JahresanfangBisHeute(text);
      case 8: return new FreierZeitraum(text);
    }
    return null;
  }
}